PROGRAM ILN

!!!!!!!!! regarding the data file, it is a column vector containing "(# of subjects)*22" bids in total. 
!!!!!!!!! for each player, first- and second-half bids are sorted according to the corresponding signals.
!!!!!!!!! i.e., for each n, ((n-1)*22+1) is the bid for signal = 1 in the first half, ((n-1)*22+12) is the bid for signal = 1 in the second half, etc 
!!!!!!!!! also, since the maximum bid 1000000.00 is a large number, you have to choose the right precision setting for real numbers and integers.

IMPLICIT NONE

INTEGER :: i,j,k,l		! for DO loop
INTEGER :: jj		! for arbitrary use

INTEGER :: name		! 1 = Baseline, 2 = ShowBidFn, 3 = MinBid
INTEGER :: nos, nob2	! nos = # of sbjects, nob2 = # of overall bids (=nos*22)

REAL, DIMENSION(:), ALLOCATABLE :: b	! variable for data
REAL, DIMENSION(:,:), ALLOCATABLE :: bid1	! 1st-half bids
REAL, DIMENSION(:,:), ALLOCATABLE :: bid2	! 2nd-half bids

REAL :: c			! for data reading

INTEGER, DIMENSION(:), ALLOCATABLE :: monotone	! for checking monotonicity of bids in 1sr half (weakly monotone = 1, otherwise = 0)
INTEGER :: nomono = 0				! number of players who are monotone		

REAL, DIMENSION(11) :: maxcheck			! used for sorting the data
REAL, DIMENSION(:,:), ALLOCATABLE :: dummy1		! variable = bid1, later sorted

REAL, DIMENSION(:,:), ALLOCATABLE :: oppb, oppv	! from dummy1, treated as "opponent's bids", opponent's signal

REAL, DIMENSION(:,:), ALLOCATABLE :: bidsignal	! oppb + signal

REAL, DIMENSION(:,:), ALLOCATABLE :: mid		! midpoints
REAL, DIMENSION(:,:), ALLOCATABLE :: sb		! self bids (consisting of "oppb" and "mid")

REAL, DIMENSION(:,:,:), ALLOCATABLE :: m		! value (subject #, own signal, oppv)
REAL, DIMENSION(:,:,:), ALLOCATABLE :: a		! weights (subject number, sb, oppb)
REAL, DIMENSION(:,:,:), ALLOCATABLE :: u		! payoffs (subject number, sb, signal)

REAL, DIMENSION(:,:), ALLOCATABLE :: maxu		! for identification of max payoff
INTEGER, DIMENSION(:,:,:), ALLOCATABLE :: g		! 1 for max u, 0 otherwise

INTEGER, DIMENSION(:,:), ALLOCATABLE :: noi		! number of BR intervals

INTEGER :: oneminusone

INTEGER, DIMENSION(:,:,:), ALLOCATABLE :: binf		! 3rd item = interval #, -2 if closed, -1 if open
INTEGER, DIMENSION(:,:,:), ALLOCATABLE :: bsup		! 3rd item = interval #, 2 if closed, 1 if open
REAL, DIMENSION(:,:,:), ALLOCATABLE :: inf			! 3rd item = interval # 
REAL, DIMENSION(:,:,:), ALLOCATABLE :: sup			! 3rd item = interval #

REAL, DIMENSION(:,:,:), ALLOCATABLE :: dinf			! for discrete version, corresponding to "inf"
REAL, DIMENSION(:,:,:), ALLOCATABLE :: dsup			! for discrete version, corresponding to "sup"

INTEGER, DIMENSION(:,:), ALLOCATABLE :: br			! 1 if BR, 0 otherwise
INTEGER, DIMENSION(:), ALLOCATABLE :: nbr			! number of BRs


REAL :: avebr = 0.			! average # of BR per subject = sum(nbr)/nos	

INTEGER :: nameconstant		! 26 for BL, 114 for SBF, 88 for MB

INTEGER :: aggorind

!!!!! reading the name !!!!

loop1: DO
	WRITE (*,*) 'You have to choose one of the following numbers'
	WRITE (*,*) '1 = Baseline, 2 = ShowBidFn, 3 = MinBid'
	WRITE (*,*) 'ENTER THE NUMBER: '
	
	READ (*,*) name

	SELECT CASE (name)
	CASE (1)			! Baseline
		nos = 62
		nob2 = 1364		! 62*22
		EXIT loop1
	CASE (2)			! ShowBidFn
		nos = 46
		nob2 = 1012		! 46*22
		EXIT loop1
	CASE (3)
		nos = 26
		nob2 = 572		! 26*22
		EXIT loop1
	CASE DEFAULT
		CYCLE loop1
	END SELECT

END DO loop1


!!!!! allocatable arrays !!!!!


ALLOCATE( b(nob2) )

ALLOCATE( bid1(nos,11) )
ALLOCATE( bid2(nos,11) )

ALLOCATE( monotone(nos) )

ALLOCATE( dummy1(nos,11) )

ALLOCATE( oppb(nos,11) )
ALLOCATE( oppv(nos,11) )

ALLOCATE( bidsignal(nos,22) )

ALLOCATE( mid(nos,23) )
ALLOCATE( sb(nos,45) )

ALLOCATE( m(nos,11,11) )
ALLOCATE( a(nos,45,11) )
ALLOCATE( u(nos,45,11) )

ALLOCATE( maxu(nos,11) )
ALLOCATE( g(nos,45,11) )

ALLOCATE( noi(nos,11) )

ALLOCATE( binf(nos,11,20) )		! noi <= 20
ALLOCATE( bsup(nos,11,20) )
ALLOCATE( inf(nos,11,20) )
ALLOCATE( sup(nos,11,20) )

ALLOCATE( dinf(nos,11,20) )
ALLOCATE( dsup(nos,11,20) )

ALLOCATE( br(nos,11) )
ALLOCATE( nbr(nos) )

!!!!! whether individual or aggregate

WRITE (*,*) '0 for Aggregae Summary or 1 for individual best responses in part II'

READ (*,*) aggorind


!!!!! reading the data !!!!!

SELECT CASE (name)
	CASE (1)	! Baseline
		OPEN(13,FILE='data/bl.dat',STATUS='OLD',ACTION='READ')
	CASE (2)	! ShoBidFn
		OPEN(13,FILE='data/sbf.dat',STATUS='OLD',ACTION='READ')
	CASE (3)	! Minbid
		OPEN(13,FILE='data/mb.dat',STATUS='OLD',ACTION='READ')
END SELECT

DO i = 1, nob2
        READ(13,*) c
        b(i) = c
END DO


CLOSE (UNIT=13)

!!!!! sorting the date for each player in 1st and 2nd halves !!!!

DO i = 1, nos
     DO j = 1, 11
     	bid1(i,j) = b((i-1)*22+j)
     	dummy1(i,j) = b((i-1)*22+j)
     END DO
END DO

DO i = 1, nos
     DO j = 1, 11
     	bid2(i,j) = b((i-1)*22+j+11)
     END DO
END DO

!!!!!! weak monotonicity in 1st half !!!!!

DO i = 1, nos
	monotone(i) = 0
END DO

DO i = 1, nos
     loop2: DO j = 2,11
     	IF ( bid1(i,j-1) > bid1(i,j) ) THEN
     		EXIT loop2
     	ELSE IF ( j == 11 ) THEN
     		monotone(i) = 1
     	END IF
     END DO loop2
END DO

DO i = 1, nos
	nomono = nomono + monotone(i)
END DO


!!!!!!!!!!

!!! sorting the data for "opponent" according to bids !!!

DO i = 1, nos
     DO j = 1, 11
     	maxcheck(j) = 0.
     END DO

     DO j = 1, 11	! for maxcheck !
     	DO k = 1, 11	! for dummy2 !
     	     IF ( maxcheck(12-j) <= dummy1(i,k) ) THEN
     	     	maxcheck(12-j) = dummy1(i,k)
     	     END IF
     	END DO
     
     	loop4: DO k = 1, 11
     	     IF ( dummy1(i,k) == maxcheck(12-j) ) THEN
     	     	oppb(i,12-j)=dummy1(i,k)
     	     	oppv(i,12-j)=REAL(k)-1.
     	     	dummy1(i,k) = -1.
     	     	EXIT loop4
	     END IF
     	END DO loop4
     END DO
END DO

!!!!! inserting "signals" as possible bids (mainly for minbid) !!!!!

DO i = 1, nos
		bidsignal(i,1) = 0.		! lowest signal
	DO j = 2, 12
		bidsignal(i,j) = oppb(i,j-1)
	END DO
	
	DO j = 13, 22
		bidsignal(i,j) = 11.
	END DO
END DO

DO i = 1, nos
	DO k = 1, 10			! other possible signals
		loop5: DO j = 2, 22		! note that there are 22 possible bids
			IF ( REAL(k) > bidsignal(i,j) ) CYCLE loop5		! looking for bid weakly higher than current signal
			
			DO l = 21, j, -1
				bidsignal(i,l+1) = bidsignal(i,l)		! moving the bids to the right
			END DO
			
			bidsignal(i,j) = REAL(k)			! inserting signal
			EXIT loop5
		END DO loop5
	END DO
END DO




!!!!! defining mids !!!!!


DO i = 1, nos
	mid(i,1) = 0.
	mid(i,23) = 1000000.
     		DO j = 2, 22
     			mid(i,j) = ( bidsignal(i,j-1)+bidsignal(i,j) )/2.
		END DO
END DO


!!!!! defining self's possible bids !!!!!

DO i = 1, nos
    DO j = 1, 23
    	jj = 2*j-1	! insertings mids
    	sb(i,jj) = mid(i,j)
    END DO
END DO

DO i = 1, nos
     DO j = 1, 22
     	jj = 2*j	! inserting opponent's bids
     	sb(i,jj) = bidsignal(i,j)
     END DO
END DO

!!!!! defining value of the object !!!!!

DO i = 1, nos
	DO j = 1, 11
     		DO k = 1, 11
			IF ( REAL(j)-1 >= oppv(i,k) ) THEN
     	     			m(i,j,k) = REAL(j)-1.
	     		ELSE
	     			m(i,j,k) = oppv(i,k)
	     		END IF
     		END DO
	END DO
END DO	

!!!!! defining weights	!!!!!

DO i = 1, nos
	DO j = 1, 45
     		DO k = 1, 11
     			IF ( sb(i,j) > oppb(i,k) ) THEN
     				a(i,j,k) = 2.
     			ELSE IF ( sb(i,j) < oppb(i,k) ) THEN
     	      			a(i,j,k) = 0.
     	 		ELSE
     	      			a(i,j,k) = 1.
     	 		END IF
     		END DO
	END DO
END DO

!!!!! computation of payoffs !!!!!!

DO i = 1, nos
DO j = 1, 45
DO k = 1, 11
	u(i,j,k)=0.
END DO
END DO
END DO

DO i = 1, nos
	DO j = 1, 45			! for own bids
     		DO k = 1, 11		! for own signal
     			DO l = 1, 11	! opponent's bids
     	     			u(i,j,k) = u(i,j,k) + a(i,j,l)*( m(i,k,l)-oppb(i,l) )
     			END DO
		END DO
	END DO
END DO

	!!!! This is for MinBID only !!!!!  this is required for identification of BR

	IF ( name == 3 ) THEN

	DO i = 1, nos
		DO j = 1, 45		! own bids
			DO k = 1, 11	! own signal
				IF ( sb(i,j) < REAL(k-1) ) u(i,j,k) = -1.
			END DO
		END DO
	END DO

	END IF
	
	
!!!!!! eliminating the cases where intervals are 0.01 and open - hence cannot be BR !!!!!!

DO i = 1, nos
	DO j = 1, 11
		DO k = 3, 43, 2
			IF ( sb(i,k+1) - sb(i,k-1) > 0. .AND. sb(i,k+1) - sb(i,k-1) <= 0.01 .AND. u(i,k-1,j) < u(i,k,j) ) THEN
				u(i,k,j) = -1.
			ELSE IF ( sb(i,k+1) - sb(i,k-1) > 0. .AND. sb(i,k+1) - sb(i,k-1) <= 0.01 .AND. u(i,k,j) > u(i,k+1,j) ) THEN
				u(i,k,j) = -1.
			END IF
		END DO
	END DO
END DO


!!!!!! identifying intervals - note that here we focus on continuous case !!!!!

DO i = 1, nos
	DO j = 1, 11
		maxu(i,j) = 0.
	END DO
END DO

DO i = 1, nos
	DO j = 1, 11
		DO k = 1, 45
			IF ( maxu(i,j) <= u(i,k,j)  ) THEN
				maxu(i,j) = u(i,k,j)
			END IF
		END DO
	END DO
END DO

DO i = 1, nos
	DO j = 1, 11
		DO k = 1, 45
			IF ( u(i,k,j) == maxu(i,j) ) THEN
				g(i,k,j) = 1
			ELSE 
				g(i,k,j) = 0
			END IF
		END DO
	END DO
END DO



!!!!! assigning interval !!!!!!

DO i = 1, nos
	DO j = 1, 11
		noi(i,j) = 0
	END DO
END DO

DO i = 1, nos
	DO j = 1, 11
		DO k = 1, 20
			binf(i,j,k) = 0
			inf(i,j,k) = 0.
			sup(i,j,k) = 0.
			bsup(i,j,k) = 0
		END DO
	END DO
END DO


DO i = 1, nos
	DO j = 1, 11
		DO k = 2, 44, 2		! for bidsgnals
			IF ( k == 2 .AND. g(i,k,j) == 1 ) THEN
				IF ( u(i,k-1,j) < u(i,k,j) .AND. u(i,k,j) > u(i,k+1,j) ) THEN
					noi(i,j) = noi(i,j) + 1
					binf(i,j,noi(i,j)) = -2
					inf(i,j,noi(i,j)) = sb(i,k)
					sup(i,j,noi(i,j)) = sb(i,k)
					bsup(i,j,noi(i,j)) = 2
				END IF
			ELSE IF ( k > 2 .AND. sb(i,k-2) < sb(i,k) .AND. g(i,k,j) == 1 ) THEN
				IF ( u(i,k-1,j) < u(i,k,j) .AND. u(i,k,j) > u(i,k+1,j) ) THEN
					noi(i,j) = noi(i,j) + 1
					binf(i,j,noi(i,j)) = -2
					inf(i,j,noi(i,j)) = sb(i,k)
					sup(i,j,noi(i,j)) = sb(i,k)
					bsup(i,j,noi(i,j)) = 2
				END IF
			END IF
		END DO

		oneminusone = 1		! looking for inf

		loop6 : DO k = 1, 45, 2	! corresponding to mids

			IF ( oneminusone == 1 .AND. g(i,k,j) == 1 ) THEN	! inf evaluated at mids
		     		noi(i,j)=noi(i,j)+1
			
				IF ( k == 1 ) THEN			! [0,
					binf(i,j,noi(i,j)) = -2
					inf(i,j,noi(i,j)) = 0.
					oneminusone = -1			! now look for sup
					CYCLE loop6
				END IF

				IF ( g(i,k-1,j) == 1 ) THEN
					binf(i,j,noi(i,j)) = -2
				ELSE
					binf(i,j,noi(i,j)) = -1
				END IF		
					inf(i,j,noi(i,j)) = sb(i,k-1) 		! specifying inf
						
				IF ( k == 45 ) THEN			! if above highest opponent's bid is best response
					sup(i,j,noi(i,j)) = 1000000.
					bsup(i,j,noi(i,j)) = 2
					EXIT loop6
				END IF
			
				oneminusone = -1				! now look for sup
				CYCLE loop6

			ELSE IF ( oneminusone == -1 .AND. k == 45 .AND. g(i,45,j) == 1 ) THEN		! everyting above inf is best response
		
				sup(i,j,noi(i,j)) = 1000000.
				bsup(i,j,noi(i,j)) = 2
				EXIT loop6

			ELSE IF ( oneminusone == -1 .AND. g(i,k,j) == 0 ) THEN	! sup
			
				sup(i,j,noi(i,j)) = sb(i,k-1)		! specifying sup
				IF ( g(i,k-1,j) == 1 ) THEN
					bsup(i,j,noi(i,j)) = 2
				ELSE 
					bsup(i,j,noi(i,j)) = 1
				END IF
			
				oneminusone = 1
				CYCLE loop6
		
			END IF
		END DO loop6
			
	END DO
END DO


!!!!!  BR in discrete setting !!!!!

DO i = 1, nos
	DO j = 1, 11
		DO k = 1, 20
			dinf(i,j,k) = 0.
			dsup(i,j,k) = 0.
		END DO
	END DO
END DO

DO i = 1, nos
	DO j = 1, 11
		DO k = 1, noi(i,j)
			IF ( inf(i,j,k) == sup(i,j,k) ) THEN
				dinf(i,j,k) = inf(i,j,k)
				dsup(i,j,k) = sup(i,j,k)	
			ELSE IF ( binf(i,j,k) == -2 .AND. bsup(i,j,k) == 2 ) THEN
				dinf(i,j,k) = inf(i,j,k)
				dsup(i,j,k) = sup(i,j,k)
			ELSE IF ( binf(i,j,k) == -1 .AND. bsup(i,j,k) == 2 ) THEN
				dinf(i,j,k) = inf(i,j,k) + 0.01
				dsup(i,j,k) = sup(i,j,k) 
			ELSE IF ( binf(i,j,k) == -2 .AND. bsup(i,j,k) == 1 ) THEN
				dinf(i,j,k) = inf(i,j,k)
				dsup(i,j,k) = sup(i,j,k) - 0.01
			ELSE
				dinf(i,j,k) = inf(i,j,k) + 0.01
				dsup(i,j,k) = sup(i,j,k) - 0.01
			END IF
		END DO
	END DO
END DO

!!!!! identification of BRs !!!!!

DO i = 1, nos
	nbr(i) = 0
	DO j = 1, 11
		br(i,j) = 0
	END DO
END DO

DO i = 1, nos
	DO j = 1, 11
		loop7: DO k = 1, noi(i,j) 
			IF ( bid2(i,j) >= dinf(i,j,k) .AND. bid2(i,j) <= dsup(i,j,k) ) THEN	! to avoid rounding error
				br(i,j) = 1
				EXIT loop7
			END IF
		END DO loop7
	END DO
END DO

DO i = 1, nos
	DO j = 1, 11
		nbr(i) = nbr(i) + br(i,j)
	END DO
END DO





!!!!! aggregation !!!!!

DO i = 1, nos
	avebr = avebr + REAL(nbr(i))
END DO

avebr = avebr / REAL(nos)


!!!!!! outputs !!!!!!

IF ( name == 1 ) THEN
	nameconstant = 26
ELSE IF ( name == 2 ) THEN
	nameconstant = 114
ELSE
	nameconstant = 88
END IF

IF ( name == 1 .AND. aggorind == 0 ) THEN

        OPEN ( UNIT=30, FILE='results/Baseline-a.txt', STATUS='REPLACE' )

                WRITE(30,*) ' Baseline '
                WRITE(30,*) '   #   #BR   Mono1  '
	        
                DO i = 1, nos
		        WRITE(30,2000) i+nameconstant, nbr(i), monotone(i)
		        2000 FORMAT (' ', I5, I5, I5)
	        END DO
	
	        WRITE(30,2001) avebr, nomono
	        2001 FORMAT (' ', F10.3, I5 )
	
	CLOSE ( UNIT=30 )

ELSE IF ( name == 2 .AND. aggorind == 0 ) THEN

        OPEN ( UNIT=30, FILE='results/ShowBidFn-a.txt', STATUS='REPLACE' )

                WRITE(30,*) ' ShowBidFn '
                WRITE(30,*) '   #   #BR   Mono1  '
	
	        DO i = 1, nos
		        WRITE(30,2000) i+nameconstant, nbr(i), monotone(i)
                	END DO
	
	        WRITE(30,2001) avebr, nomono

        CLOSE ( UNIT=30 )
        
ELSE IF ( name == 3 .AND. aggorind == 0 ) THEN

        OPEN ( UNIT=30, FILE='results/MinBid-a.txt', STATUS='REPLACE' )
        
                WRITE(30,*) ' MinBid '
                	WRITE(30,*) '   #   #BR   Monotone1 '
	
	        DO i = 1, nos
		        WRITE(30,2000) i+nameconstant, nbr(i),  monotone(i)
	        END DO
	
	        WRITE(30,2001) avebr, nomono

        CLOSE ( UNIT=30 )

END IF

!!!!!! intervals !!!!!

IF (  name== 1 .AND. aggorind == 1 ) THEN

        OPEN ( UNIT=30, FILE='results/Baseline-i.txt', STATUS='REPLACE' )

        DO i = 1, nos
	        DO j = 1, 11
		
	        SELECT CASE ( noi(i,j) )
			
	        CASE (1)
		        IF ( j == 1 ) THEN
			        WRITE(30,3000) i+nameconstant, j-1, dinf(i,j,1), dsup(i,j,1)
			        3000 FORMAT ( ' ', I5, I3, ' [', F11.2, ',', F11.2, ']' )
		        ELSE
			        WRITE(30,3001) j-1, dinf(i,j,1), dsup(i,j,1)
			        3001 FORMAT ( '      ', I3, ' [', F11.2, ',', F11.2, ']' )
		        END IF
		
	        CASE (2)
		        IF ( j == 1 ) THEN
			        WRITE(30,3002) i+nameconstant, j-1, dinf(i,j,1), dsup(i,j,1), dinf(i,j,2), dsup(i,j,2)
			        3002 FORMAT ( ' ', I5, I3, ' [', F11.2, ',', F11.2, '], [', F11.2, ',' F11.2, ']' )
		        ELSE
			        WRITE(30,3003) j-1, dinf(i,j,1), dsup(i,j,1), dinf(i,j,2), dsup(i,j,2)
			        3003 FORMAT ( '      ', I3, ' [', F11.2, ',', F11.2, '], [', F11.2, ',' F11.2, ']' )
		END IF
	
	        CASE (3)
		        IF ( j == 1 ) THEN
			        WRITE(30,3004) i+nameconstant, j-1, dinf(i,j,1), dsup(i,j,1), dinf(i,j,2), dsup(i,j,2), dinf(i,j,3), dsup(i,j,3)
			        3004 FORMAT ( ' ', I5, I3, ' [', F11.2, ',', F11.2, '], [', F11.2, ',' F11.2, '], [', F11.2, ',', F11.2, ']' )
		        ELSE
			        WRITE(30,3005) j-1, dinf(i,j,1), dsup(i,j,1), dinf(i,j,2), dsup(i,j,2), dinf(i,j,3), dsup(i,j,3)
			        3005 FORMAT ( '       ', I3, ' [', F11.2, ',', F11.2, '], [', F11.2, ',' F11.2, '], [', F11.2, ',' F11.2, ']' )
		        END IF
	        END SELECT
	
	        END DO
        END DO

        CLOSE ( UNIT=30 )

ELSE IF ( name==2 .AND. aggorind == 1 ) THEN

        OPEN ( UNIT=30, FILE='results/ShowBidFn-i.txt', STATUS='REPLACE' )

        DO i = 1, nos
	        DO j = 1, 11
		
	        SELECT CASE ( noi(i,j) )
			
	        CASE (1)
		        IF ( j == 1 ) THEN
			        WRITE(30,3000) i+nameconstant, j-1, dinf(i,j,1), dsup(i,j,1)
		        ELSE
			        WRITE(30,3001) j-1, dinf(i,j,1), dsup(i,j,1)
		        END IF
		
	        CASE (2)
		        IF ( j == 1 ) THEN
			        WRITE(30,3002) i+nameconstant, j-1, dinf(i,j,1), dsup(i,j,1), dinf(i,j,2), dsup(i,j,2)
		        ELSE
			        WRITE(30,3003) j-1, dinf(i,j,1), dsup(i,j,1), dinf(i,j,2), dsup(i,j,2)
		END IF
	
	        CASE (3)
		        IF ( j == 1 ) THEN
			        WRITE(30,3004) i+nameconstant, j-1, dinf(i,j,1), dsup(i,j,1), dinf(i,j,2), dsup(i,j,2), dinf(i,j,3), dsup(i,j,3)
		        ELSE
			        WRITE(30,3005) j-1, dinf(i,j,1), dsup(i,j,1), dinf(i,j,2), dsup(i,j,2), dinf(i,j,3), dsup(i,j,3)
		        END IF
	        END SELECT
	
	        END DO
        END DO

        CLOSE ( UNIT=30 )
        
        
ELSE IF ( name==3 .AND. aggorind==1 ) THEN

        OPEN ( UNIT=30, FILE='results/MinBid-i.txt', STATUS='REPLACE' )

        DO i = 1, nos
	        DO j = 1, 11
		
	        SELECT CASE ( noi(i,j) )
			
	        CASE (1)
		        IF ( j == 1 ) THEN
			        WRITE(30,3000) i+nameconstant, j-1, dinf(i,j,1), dsup(i,j,1)
		        ELSE
			        WRITE(30,3001) j-1, dinf(i,j,1), dsup(i,j,1)
		        END IF
		
	        CASE (2)
		        IF ( j == 1 ) THEN
			        WRITE(30,3002) i+nameconstant, j-1, dinf(i,j,1), dsup(i,j,1), dinf(i,j,2), dsup(i,j,2)
		        ELSE
			        WRITE(30,3003) j-1, dinf(i,j,1), dsup(i,j,1), dinf(i,j,2), dsup(i,j,2)
		END IF
	
	        CASE (3)
		        IF ( j == 1 ) THEN
			        WRITE(30,3004) i+nameconstant, j-1, dinf(i,j,1), dsup(i,j,1), dinf(i,j,2), dsup(i,j,2), dinf(i,j,3), dsup(i,j,3)
		        ELSE
			        WRITE(30,3005) j-1, dinf(i,j,1), dsup(i,j,1), dinf(i,j,2), dsup(i,j,2), dinf(i,j,3), dsup(i,j,3)
		        END IF
	        END SELECT
	
	        END DO
        END DO

        CLOSE ( UNIT=30 )


END IF

END PROGRAM ILN
